@@ -69,6 +69,7 @@ try:
     from . import demos
     from . import features
     from . import morph
+    from . import polygon
     from . import segmentation
 except ImportError: # pragma: no cover
     import sys
@@ -146,6 +147,8 @@ __all__ = [
     'imsave',
     'label',
     'labeled_sum',
+    'locmax',
+    'locmin',
     'majority_filter',
     'median_filter',
     'moments',
@@ -165,6 +168,7 @@ __all__ = [
     'demos',
     'morph',
     'features',
+    'polygon',
     'segmentation',
 
     'test',
