@@ -3,13 +3,21 @@ from mahotas.io import error_imread, error_imsave
 from nose.tools import raises
 from os import path
 import mahotas as mh
+from nose.tools import with_setup
+
+_testimgname = '/tmp/mahotas_test.png'
+def _remove_image(filename=_testimgname):
+    import os
+    try:
+        os.unlink(filename)
+    except OSError:
+        pass
 
 filename = path.join(
             path.dirname(__file__),
             'data',
             'rgba.png')
 
-
 def skip_on(etype):
     from functools import wraps
     def skip_on2(test):
@@ -45,14 +53,3 @@ def test_as_grey():
     im = mh.imread(filename, as_grey=1)
     assert im.ndim == 2
 
-@skip_on(ImportError)
-def test_matplotlibwrap():
-    filename = path.join(
-            path.dirname(__file__),
-            '..',
-            'demos',
-            'data',
-            'lena.jpg')
-    import mahotas.io.matplotlibwrap
-    im = mahotas.io.matplotlibwrap.imread(filename)
-    assert im.shape == (512,512,3)
