@@ -3,30 +3,30 @@ import mahotas
 import mahotas as mh
 import sys
 from nose.tools import raises
+S = np.array([
+    [0,0,0,0],
+    [0,1,2,1],
+    [1,1,1,1],
+    [0,0,1,0],
+    [1,1,1,1],
+    [1,2,2,1],
+    [1,1,2,2]
+    ])
+M = np.array([
+    [0,0,0,0],
+    [0,0,1,0],
+    [0,0,0,0],
+    [0,0,0,0],
+    [0,0,0,0],
+    [0,2,0,0],
+    [0,0,0,0],
+    ])
 
 def test_watershed():
-    S = np.array([
-        [0,0,0,0],
-        [0,1,2,1],
-        [1,1,1,1],
-        [0,0,1,0],
-        [1,1,1,1],
-        [1,2,2,1],
-        [1,1,2,2]
-        ])
-    M = np.array([
-        [0,0,0,0],
-        [0,0,1,0],
-        [0,0,0,0],
-        [0,0,0,0],
-        [0,0,0,0],
-        [0,2,0,0],
-        [0,0,0,0],
-        ])
-    def cast_test(M,S,dtype):
-        M = M.astype(dtype)
-        S = S.astype(dtype)
-        W = mahotas.cwatershed(2-S,M)
+    def cast_test(dtype):
+        St = S.astype(dtype)
+        Mt = M.astype(int)
+        W = mahotas.cwatershed(2-St,Mt)
         assert sys.getrefcount(W) == 2
         assert np.all(W == np.array([[1, 1, 1, 1],
                [1, 1, 1, 1],
@@ -35,8 +35,17 @@ def test_watershed():
                [2, 2, 2, 2],
                [2, 2, 2, 2],
                [2, 2, 2, 2]]))
-    for d in [np.uint8, np.int8, np.uint16, np.int16, np.int32, np.uint32,int]:
-        yield cast_test, M, S, d
+    for d in [np.uint8, np.int8, np.uint16, np.int16, np.int32, np.uint32,int,
+                 np.float32, np.float64, np.float128, float]:
+        yield cast_test, d
+
+
+@raises(TypeError)
+def test_float16():
+    dtype = np.float16
+    St = S.astype(dtype)
+    Mt = M.astype(int)
+    mh.cwatershed(2-St,Mt)
 
 
 def test_watershed2():
@@ -56,6 +65,7 @@ def test_mismatched_array_markers():
     mahotas.cwatershed(S, markers)
 
 def test_mix_types():
+    "[watershed regression]: Mixing types of surface and marker arrays used to cause crash"
     f = np.zeros((64,64), np.uint16)
     f += (np.indices(f.shape)[1]**2).astype(np.uint16)
     f += ((np.indices(f.shape)[0]-23)**2).astype(np.uint16)
@@ -66,7 +76,7 @@ def test_mix_types():
 
 
 def test_overflow():
-    '''Test whether we can force an overflow in the output of cwatershed
+    '''[watershed regression]: Try to force overflow on the output
 
     This was reported as issue #41 on github:
 
@@ -113,3 +123,15 @@ def test_watershed_labeled():
     labeled = mh.cwatershed(S, M)
     sizes = mh.labeled.labeled_sum(S, labeled)
     assert len(sizes) == labeled.max() + 1
+
+
+def test_float_input():
+    "[watershed]: Compare floating point input with integer input"
+    f = np.random.random((128,64))
+    f = mh.gaussian_filter(f, 8.)
+    f = mh.gaussian_filter(f, 8.)
+    markers,_ = mh.label(mh.regmin(f))
+    f = np.round(f * 2**30)
+    wf = mh.cwatershed(f / 2**30., markers)
+    w32 = mh.cwatershed(f.astype(np.int32), markers)
+    assert (wf == w32).mean() > .999
